@@ -1,4 +1,4 @@
-#$Id: SeqIO.pm 508 2009-10-21 21:36:38Z maj $
+#$Id: SeqIO.pm 513 2009-10-22 18:09:34Z maj $
 # PerlIO layer for sequence format with BioPerl guts
 # Enjoy!
 package PerlIO::via::SeqIO;
@@ -11,7 +11,7 @@ use IO::String;
 use IO::Seekable;
 use File::Temp qw(tempfile);
 use Exporter;
-our $VERSION = '0.02';
+our $VERSION = '0.021';
 our @ISA = qw(Exporter);
 our @EXPORT = qw(open);
 our @EXPORT_OK = qw(O T);
@@ -328,17 +328,20 @@ sub PRINT{
     my $ios = $$o{io_string};
     my $ret = 0;
     foreach (@args) {
-	if ($_ =~ /HASH/) { # string rep of object
-	    $_ = $OBJS{$_};
-	    $$o{engine}->write_seq($_);
-	    $ios->pos(0); # seek to top
-	    my $line = join('', <$ios>);
-	    $ios->pos(0); ${$ios->string_ref}='';
-	    $self->write($line, length $line);
-	    undef $OBJS{$_}; # clean up
-	}
-	else { # write the raw buffer
-	    $self->write($_, length);
+	my @input = split( /(Bio::.*?=HASH\(0x[0-9a-f]+\)\s)/);
+	foreach my $item (@input) {
+	    if ($item =~ /HASH/) { # string rep of object
+		$item = $OBJS{$item};
+		$$o{engine}->write_seq($item);
+		$ios->pos(0); # seek to top
+		my $line = join('', <$ios>);
+		$ios->pos(0); ${$ios->string_ref}='';
+		$self->write($line, length $line);
+		undef $OBJS{$item}; # clean up
+	    }
+	    else { # write the raw buffer
+		$self->write($item, length);
+	    }
 	}
     }
     1;
@@ -474,7 +477,7 @@ allows
  cat my.gcg | perl your.pl > out
 
 where C<your.pl> can read STDIN and acquire the sequence objects by
-using the object getter L</UTILITIES/O()>. The format
+using the object getter L<O()|/UTILITIES>. The format
 of the input in this case will be guessed by the C<Bio::SeqIO>
 machinery.
 
@@ -503,7 +506,7 @@ This does what you mean:
  }
 
 However, C<$_> here is not the sequence object itself. To get that use 
-the all-purpose object getter L</UTILITIES/O()>:
+the all-purpose object getter L<O()|/UTILITIES>:
 
  while (<$in>) {
    print join("\t", O($_)->id, O($_)->desc), "\n";
@@ -511,7 +514,7 @@ the all-purpose object getter L</UTILITIES/O()>:
 
 =item Writing a I<de novo> sequence object
 
-Use the L</UTILITIES/T()> mapper to convert a Bio::Seq object into a thing that can be formatted by C<via(SeqIO)>:
+Use the L<T()|/UTILITIES> mapper to convert a Bio::Seq object into a thing that can be formatted by C<via(SeqIO)>:
 
  open($seqfh, ">:via(SeqIO::embl)", "my.embl");
  my $result = Bio::SearchIO->new( -file=>'my.blast' )->next_result;
@@ -527,10 +530,18 @@ Use the L</UTILITIES/T()> mapper to convert a Bio::Seq object into a thing that
 Interspersing plain text among your sequences is easy; just print the
 desired text to the handle. See the L</SYNOPSIS>.
 
+Even the following works:
+
+ open($in, "<:via(SeqIO)", 'my.fas')
+ open($out, ">:via(SeqIO::embl)", 'annotated.txt');
+
+ $seq = <$in>;
+ print $out "In EMBL format, the sequence would be rendered:", $s;
+
 =item Switching write formats
 
 You can also easily switch write formats. (Why? Because...who knows?)
-Use C<set_write_format> off the tied handle object:
+Use L<set_write_format|/UTILITIES> off the tied handle object:
 
  open($in, "<:via(SeqIO)", 'my.fas')
  open($out, ">:via(SeqIO::embl)", 'multi.txt');
@@ -592,8 +603,9 @@ In the C<PerlIO::via::SeqIO> namespace. To use, do
  use PerlIO::via::SeqIO qw(open O T);
 
 (The C<open> hook needs to be available for the package to
-function. It is a member of C<@EXPORT>. See
-L</IMPLEMENTATION/C<PerlIO::via::SeqIO> exports C<open()>>.)
+function. It is a member of C<@EXPORT>. See L</IMPLEMENTATION> for
+details.
+
 
 =head2 O()
 
@@ -629,7 +641,7 @@ L</IMPLEMENTATION/C<PerlIO::via::SeqIO> exports C<open()>>.)
 
 =head1 SEE ALSO
 
-L<perlio>, L<PerlIO::via>, L<Bio::SeqIO>, L<Bio::Seq>, 
+L<PerlIO|perlio>, L<PerlIO::via>, L<Bio::SeqIO>, L<Bio::Seq>, 
 L<http://bioperl.org>
 
 =head1 AUTHOR - Mark A. Jensen
